@@ -10,7 +10,13 @@ describe 'murano::db::sync' do
         :path        => '/usr/bin',
         :user        => 'murano',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[murano::install::end]',
+                         'Anchor[murano::config::end]',
+                         'Anchor[murano::dbsync::begin]'],
+        :notify      => 'Anchor[murano::dbsync::end]',
       )
     end
 
